
"use strict";

this.name    = "Active Crosshairs"; // "Wildeblood", 2014.
this.version = "1.0";

/* ====================================================================================
			VARIABLES
======================================================================================= */

this.$filename = "crosshairs-selection-";
this.$minSuffix = 1;
this.$maxSuffix = 7;
this.$suffix = [[null,null,null,null,null],	// Docked.
	[7,7,7,7,7],	// Cruising.
	[7,1,2,6,5],	// Mass-locked.
	[7,1,2,6,5],	// Hostiles.
	[3,3,3,3,3]];	// Energy critical, low altitude or high temperature.

this._numberForWeaponType = function (weapon)
	{
	switch(weapon.equipmentKey)
		{
		case "EQ_WEAPON_PULSE_LASER":
			{
			return 1;
			}
		case "EQ_WEAPON_BEAM_LASER":
			{
			return 2;
			}
		case "EQ_WEAPON_MINING_LASER":
			{
			return 3;
			}
		case "EQ_WEAPON_MILITARY_LASER":
			{
			return 4;
			}
		default:
			{
			return 0;
			}
		}
	}

/* ====================================================================================
			AUTOMATIC CROSS-HAIRS CHANGES
======================================================================================= */

this.alertConditionChanged = function(alertLevel, oldLevel)
	{
	if (alertLevel == 3 && !player.alertHostiles) {alertLevel = 4};
	player.ship.crosshairs = this.$filename + this.$suffix[alertLevel][this._numberForWeaponType(player.ship.currentWeapon)] + ".plist";
	}

this.viewDirectionChanged = function(viewString)
	{
	if (this.$override)
		{
		player.ship.crosshairs = this.$filename + this.$suffix[3][this._numberForWeaponType(player.ship.currentWeapon)] + ".plist";
		}
	else
		{
	     this.alertConditionChanged(player.alertCondition, player.alertCondition);
		}
	}

this.compassTargetChanged = function(whom, mode)
	{
	if (mode === "COMPASS_MODE_TARGET")
		{
		player.ship.crosshairs = this.$filename + this.$suffix[3][this._numberForWeaponType(player.ship.currentWeapon)] + ".plist";
		this.$override = true;
		}
	else if (this.$override && !player.alertHostiles)
		{
		this.alertConditionChanged(player.alertCondition, 3);
		this.$override = false;
		}
	}

/* ====================================================================================
			SELECT NEW CROSS-HAIR WHEN EQUIPMENT IS ACTIVATED
======================================================================================= */

this._activated = function()
	{
	var weapon = this._numberForWeaponType(player.ship.currentWeapon);
     var alertLevel = player.alertCondition;
	if (alertLevel == 3 && player.alertHostiles == false) {alertLevel = 4};
	if (player.ship.compassMode === "COMPASS_MODE_TARGET") {alertLevel = 3};

     this.$suffix[alertLevel][weapon] += 1;
	if (this.$suffix[alertLevel][weapon] > this.$maxSuffix)
		{
		this.$suffix[alertLevel][weapon] = this.$minSuffix;
		}
	player.ship.crosshairs = this.$filename + this.$suffix[alertLevel][weapon] + ".plist";
	}

this._mode = function()
	{
	var weapon = this._numberForWeaponType(player.ship.currentWeapon);
     var alertLevel = player.alertCondition;
	if (alertLevel == 3 && player.alertHostiles == false) {alertLevel = 4};
	if (player.ship.compassMode === "COMPASS_MODE_TARGET") {alertLevel = 3};

     this.$suffix[alertLevel][weapon] -= 1;
	if (this.$suffix[alertLevel][weapon] < this.$minSuffix)
		{
		this.$suffix[alertLevel][weapon] = this.$maxSuffix;
		}
	player.ship.crosshairs = this.$filename + this.$suffix[alertLevel][weapon] + ".plist";
	}

/* ====================================================================================
			AWARD EQUIPMENT AT START-UP
======================================================================================= */

this.startUpComplete = function()
	{
	if (player.ship.equipmentStatus("EQ_SELECTABLE_CROSSHAIRS") !== "EQUIPMENT_OK")
		{
		player.ship.awardEquipment("EQ_SELECTABLE_CROSSHAIRS");
		player.consoleMessage("Active cross-hairs installed.", 10);
		}
	if (missionVariables.active_crosshairs)
		{
		this.$suffix = JSON.parse(missionVariables.active_crosshairs);
		}
	delete this.startUpComplete;
	}

    this.playerWillSaveGame = function () {
        "use strict";
        missionVariables.active_crosshairs = JSON.stringify(this.$suffix);
    }

/* ====================================================================================
			COPYRIGHT NOTICE

	(C)2014, Wildeblood. All rights reserved. 
	Free to use, but DO NOT PROMULGATE MODIFIED VERSIONS.

This was created by some fellow with the user name "Wildeblood" on the Oolite forums, 
he'll tell you his real name if you bother to ask.
To use means to play with, modify or re-use in whole or in part, and to distribute freely.
To use DOES NOT imply to use for commercial gain, which would be a breach of copyright.
To promulgate means to make official announcements.
======================================================================================= */
